==> charlatan_0.5.0.tar.gz: charlatan/R/person-provider-da_DK.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/dk_DK/__init__.py

person_formats_da_dk = c(
  '{{first_names_male}} {{last_names}}',
  '{{first_names_male}} {{last_names}}',
  '{{first_names_male}} {{last_names}}',
  '{{first_names_male}} {{last_names}}',
  '{{first_names_male}} {{last_names1}}-{{last_names2}}',
  '{{first_names_female}} {{last_names}}',
  '{{first_names_female}} {{last_names}}',
  '{{first_names_female}} {{last_names}}',
  '{{first_names_female}} {{last_names}}',
  '{{first_names_female}} {{last_names1}}-{{last_names2}}',
  '{{prefixes_male}} {{first_names_male}} {{last_names}}',
  '{{prefixes_female}} {{first_names_female}} {{last_names}}',
  '{{prefixes_male}} {{first_names_male}} {{last_names}}',
  '{{prefixes_female}} {{first_names_female}} {{last_names}}'
)

person_first_names_male_da_dk = c(
  "Adam",
  "Albert",
  "Aksel",
  "Alex",
  "Alexander",
  "Alf",
  "Allan",
  "Alvin",
  "Anders",
  "Andr\u00e9",
  "Andreas",
  "Anton",
  "Arne",
  "Asger",
  "ugust",
  "Benjamin",
  "Benny",
  "Bent",
  "Bertil",
  "Bertram",
  "Birger",
  "Bjarne",
  "Bo",
  "Bob",
  "Bobby",
  "Boe",
  "Boris",
  "Borris",
  "Brian",
  "Bruno",
  "B\u00f8je",
  "B\u00f8rge",
  "Carl",
  "Carlo",
  "Carsten",
  "Casper",
  "Christian",
  "Christoffer",
  "Christopher",
  "Claus",
  "Clavs",
  "Curt",
  "Dan",
  "Daniel",
  "Danny",
  "David",
  "Dennis",
  "Ebbe",
  "Einar",
  "Einer",
  "Elias",
  "Emil",
  "Eric",
  "Erik",
  "Erling",
  "Ernst",
  "Esben",
  "Finn",
  "Flemming",
  "Frank",
  "Frans",
  "Freddy",
  "Frede",
  "Frederik",
  "Frode",
  "Georg",
  "George",
  "Gert",
  "Gorm",
  "Gunnar",
  "Gunner",
  "Gustav",
  "Hans",
  "Helge",
  "Henrik",
  "Henry",
  "Herbert",
  "Herman",
  "Hjalte",
  "Holger",
  "Hugo",
  "Ib",
  "Ivan",
  "Iver",
  "Jack",
  "Jacob",
  "Jakob",
  "James",
  "Jan",
  "Jano",
  "Jarl",
  "Jean",
  "Jens",
  "Jeppe",
  "Jesper",
  "Jim",
  "Jimmy",
  "Joachim",
  "Joakim",
  "Johan",
  "Johannes",
  "John",
  "Johnnie",
  "Johnny",
  "Jon",
  "Jonas",
  "Jonathan",
  "Julius",
  "J\u00f8rgen",
  "Karl",
  "Karlo",
  "Karsten",
  "Kaspar",
  "Kasper",
  "Keld",
  "Ken",
  "Kenn",
  "Kenneth",
  "Kenny",
  "Kent",
  "Kim",
  "Kjeld",
  "Klaus",
  "Klavs",
  "Kristian",
  "Kurt",
  "K\u00e5re",
  "Lars",
  "Lasse",
  "Laurits",
  "Laus",
  "Laust",
  "Leif",
  "Lennarth",
  "Lucas",
  "Ludvig",
  "Mads",
  "Magnus",
  "Malthe",
  "Marcus",
  "Marius",
  "Mark",
  "Martin",
  "Mathias",
  "Matthias",
  "Michael",
  "Mik",
  "Mikael",
  "Mike",
  "Mikkel",
  "Mogens",
  "Morten",
  "Nick",
  "Nicklas",
  "Nicolai",
  "Nicolaj",
  "Niels",
  "Nikolai",
  "Nikolaj",
  "Nils",
  "Noah",
  "Ole",
  "Olfert",
  "Oliver",
  "Oscar",
  "Oskar",
  "Osvald",
  "Otto",
  "Ove",
  "Palle",
  "Patrick",
  "Paw",
  "Peder",
  "Per",
  "Pete",
  "Peter",
  "Paul",
  "Philip",
  "Poul",
  "Preben",
  "Ragnar",
  "Ragner",
  "Rasmus",
  "Ren\u00e9",
  "Richard",
  "Richardt",
  "Robert",
  "Robin",
  "Rolf",
  "Ron",
  "Ronni",
  "Ronnie",
  "Ronny",
  "Ruben",
  "Rune",
  "Sam",
  "Sebastian",
  "Silas",
  "Simon",
  "Sonny",
  "Steen",
  "Stefan",
  "Sten",
  "Stephan",
  "Steve",
  "Steven",
  "Stig",
  "Svenning",
  "S\u00f8ren",
  "Tage",
  "Tejs",
  "Thomas",
  "Tim",
  "Timmy",
  "Tobias",
  "Tom",
  "Tommy",
  "Tonny",
  "Torben",
  "Troels",
  "Uffe",
  "Ulf",
  "Ulrik",
  "Vagn",
  "Valdemar",
  "Verner",
  "Victor",
  "Villads",
  "Werner",
  "William",
  "Yan",
  "Yannick",
  "Yngve",
  "Zacharias",
  "Ziggy",
  "\u00d8ivind",
  "\u00d8jvind",
  "\u00d8rni",
  "\u00d8vli",
  "\u00d8ystein",
  "\u00d8yvind",
  "\u00c5bj\u00f8rn",
  "Aage",
  "\u00c5ge"
)

person_first_names_female_da_dk = c(
  "Abelone",
  "Agnes",
  "Agnete",
  "Alberte",
  "Alma",
  "Amalie",
  "Amanda",
  "Andrea",
  "Ane",
  "Anette",
  "Anna",
  "Anne",
  "Annemette",
  "Annette",
  "Asta",
  "Astrid",
  "Benedicte",
  "Benedikte",
  "Bente",
  "Benthe",
  "Berit",
  "Berta",
  "Beth",
  "Bettina",
  "Birgit",
  "Birgitte",
  "Birte",
  "Birthe",
  "Bitten",
  "Bodil",
  "Britt",
  "Britta",
  "Camilla",
  "Carina",
  "Carla",
  "Caroline",
  "Cathrine",
  "Catrine",
  "Cecilie",
  "Charlotte",
  "Christina",
  "Christine",
  "Cirkeline",
  "Clara",
  "Connie",
  "Conny",
  "Dagmar",
  "Dagny",
  "Daniella",
  "Dina",
  "Ditte",
  "Doris",
  "Dorte",
  "Dorthe",
  "Edith",
  "Elin",
  "Elisabeth",
  "Ella",
  "Ellen",
  "Elna",
  "Else",
  "Elsebeth",
  "Emilie",
  "Emily",
  "Emma",
  "Erna",
  "Esmarelda",
  "Ester",
  "Filippa",
  "Frederikke",
  "Freja",
  "Frida",
  "Gerda",
  "Gertrud",
  "Gitte",
  "Grete",
  "Grethe",
  "Gundhild",
  "Gunhild",
  "Gurli",
  "Gyda",
  "Hannah",
  "Hanne",
  "Heidi",
  "Helen",
  "Helle",
  "Henriette",
  "Herdis",
  "Iben",
  "Ida",
  "Inga",
  "Inge",
  "Ingelise",
  "Inger",
  "Ingrid",
  "Irma",
  "Isabella",
  "Jacobine",
  "Jacqueline",
  "Janne",
  "Janni",
  "Jannie",
  "Jasmin",
  "Jean",
  "Jenny",
  "Joan",
  "Johanne",
  "Jonna",
  "Josefine",
  "Josephine",
  "Julie",
  "Justina",
  "Jytte",
  "Karen",
  "Karin",
  "Karina",
  "Karla",
  "Karoline",
  "Katcha",
  "Katja",
  "Katrine",
  "Kirsten",
  "Kirstin",
  "Kirstine",
  "Klara",
  "Kristina",
  "Kristine",
  "Laura",
  "Lea",
  "Lena",
  "Lene",
  "Leonora",
  "Line",
  "Liva",
  "Lona",
  "Lone",
  "Lotte",
  "Louise",
  "L\u00e6rke",
  "Maiken",
  "Maja",
  "Majken",
  "Malene",
  "Malou",
  "Maren",
  "Margit",
  "Margrethe",
  "Maria",
  "Marianne",
  "Marie",
  "Marlene",
  "Mathilde",
  "Maya",
  "Merete",
  "Merethe",
  "Mette",
  "Mia",
  "Michala",
  "Michelle",
  "Mie",
  "Mille",
  "Mimi",
  "Minna",
  "Nadia",
  "Naja",
  "Nana",
  "Nanna",
  "Nanni",
  "Natasha",
  "Natasja",
  "Nete",
  "Nicoline",
  "Nina",
  "Nora",
  "Oda",
  "Odeline",
  "Odette",
  "Ofelia",
  "Olga",
  "Olivia",
  "Patricia",
  "Paula",
  "Paulina",
  "Pernille",
  "Pia",
  "Ragna",
  "Ragnhild",
  "Randi",
  "Rebecca",
  "Regitse",
  "Regitze",
  "Rikke",
  "Rita",
  "Ritt",
  "Ronja",
  "Rosa",
  "Ruth",
  "Sabine",
  "Sandra",
  "Sanne",
  "Sara",
  "Sarah",
  "Selma",
  "Signe",
  "Sigrid",
  "Silje",
  "Sille",
  "Simone",
  "Sine",
  "Sofia",
  "Sofie",
  "Solveig",
  "Solvej",
  "Sonja",
  "Sophie",
  "Stina",
  "Stine",
  "Susanne",
  "Sussanne",
  "Sussie",
  "Sys",
  "S\u00f8rine",
  "S\u00f8s",
  "Tammy",
  "Tanja",
  "Thea",
  "Tilde",
  "Tina",
  "Tine",
  "Tove",
  "Trine",
  "Ulla",
  "Ulrike",
  "Ursula",
  "Vera",
  "Victoria",
  "Viola",
  "Vivian",
  "Weena",
  "Winni",
  "Winnie",
  "Xenia",
  "Yasmin",
  "Yda",
  "Yrsa",
  "Yvonne",
  "Zahra",
  "Zara",
  "Zehnia",
  "Zelma",
  "Zenia",
  "\u00c5se"
)

person_first_names_da_dk = c(person_first_names_male_da_dk, person_first_names_female_da_dk)

person_last_names_da_dk = c(
  "Jensen",
  "Nielsen",
  "Hansen",
  "Pedersen",
  "Andersen",
  "Christensen",
  "Larsen",
  "S\u00f8rensen",
  "Rasmussen",
  "Petersen",
  "J\u00f8rgensen",
  "Madsen",
  "Kristensen",
  "Olsen",
  "Christiansen",
  "Thomsen",
  "Poulsen",
  "Johansen",
  "Knudsen",
  "Mortensen",
  "M\u00f8ller",
  "Jacobsen",
  "Jakobsen",
  "Olesen",
  "Frederiksen",
  "Mikkelsen",
  "Henriksen",
  "Laursen",
  "Lund",
  "Schmidt",
  "Eriksen",
  "Holm",
  "Kristiansen",
  "Clausen",
  "Simonsen",
  "Svendsen",
  "Andreasen",
  "Iversen",
  "Jeppesen",
  "Mogensen",
  "Jespersen",
  "Nissen",
  "Lauridsen",
  "Frandsen",
  "\u00d8stergaard",
  "Jepsen",
  "Kj\u00e6r",
  "Carlsen",
  "Vestergaard",
  "Jessen",
  "N\u00f8rgaard",
  "Dahl",
  "Christoffersen",
  "Skov",
  "S\u00f8ndergaard",
  "Bertelsen",
  "Bruun",
  "Lassen",
  "Bach",
  "Gregersen",
  "Friis",
  "Johnsen",
  "Steffensen",
  "Kjeldsen",
  "Bech",
  "Krogh",
  "Lauritsen",
  "Danielsen",
  "Mathiesen",
  "Andresen",
  "Brandt",
  "Winther",
  "Toft",
  "Ravn",
  "Mathiasen",
  "Dam",
  "Holst",
  "Nilsson",
  "Lind",
  "Berg",
  "Schou",
  "Overgaard",
  "Kristoffersen",
  "Schultz",
  "Klausen",
  "Karlsen",
  "Paulsen",
  "Hermansen",
  "Thorsen",
  "Koch",
  "Thygesen"
)

person_prefixes_male_da_dk = c(
  'Hr', 'Dr.', 'Prof.', 'Univ.Prof.'
)

person_prefixes_female_da_dk = c(
  'Fru', 'Dr.', 'Prof.', 'Univ.Prof.'
)

person_da_dk <- list(
  first_names = person_first_names_da_dk,
  first_names_male = person_first_names_male_da_dk,
  first_names_female = person_first_names_female_da_dk,
  last_names = person_last_names_da_dk,
  prefixes_female = person_prefixes_female_da_dk,
  prefixes_male = person_prefixes_male_da_dk
)

==> charlatan_0.5.1.tar.gz: charlatan/R/person-provider-da_DK.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/dk_DK/__init__.py

person_formats_da_dk <- c(
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names1}}-{{last_names2}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names1}}-{{last_names2}}",
  "{{prefixes_male}} {{first_names_male}} {{last_names}}",
  "{{prefixes_female}} {{first_names_female}} {{last_names}}",
  "{{prefixes_male}} {{first_names_male}} {{last_names}}",
  "{{prefixes_female}} {{first_names_female}} {{last_names}}"
)

person_first_names_male_da_dk <- c(
  "Adam",
  "Albert",
  "Aksel",
  "Alex",
  "Alexander",
  "Alf",
  "Allan",
  "Alvin",
  "Anders",
  "Andr\u00e9",
  "Andreas",
  "Anton",
  "Arne",
  "Asger",
  "ugust",
  "Benjamin",
  "Benny",
  "Bent",
  "Bertil",
  "Bertram",
  "Birger",
  "Bjarne",
  "Bo",
  "Bob",
  "Bobby",
  "Boe",
  "Boris",
  "Borris",
  "Brian",
  "Bruno",
  "B\u00f8je",
  "B\u00f8rge",
  "Carl",
  "Carlo",
  "Carsten",
  "Casper",
  "Christian",
  "Christoffer",
  "Christopher",
  "Claus",
  "Clavs",
  "Curt",
  "Dan",
  "Daniel",
  "Danny",
  "David",
  "Dennis",
  "Ebbe",
  "Einar",
  "Einer",
  "Elias",
  "Emil",
  "Eric",
  "Erik",
  "Erling",
  "Ernst",
  "Esben",
  "Finn",
  "Flemming",
  "Frank",
  "Frans",
  "Freddy",
  "Frede",
  "Frederik",
  "Frode",
  "Georg",
  "George",
  "Gert",
  "Gorm",
  "Gunnar",
  "Gunner",
  "Gustav",
  "Hans",
  "Helge",
  "Henrik",
  "Henry",
  "Herbert",
  "Herman",
  "Hjalte",
  "Holger",
  "Hugo",
  "Ib",
  "Ivan",
  "Iver",
  "Jack",
  "Jacob",
  "Jakob",
  "James",
  "Jan",
  "Jano",
  "Jarl",
  "Jean",
  "Jens",
  "Jeppe",
  "Jesper",
  "Jim",
  "Jimmy",
  "Joachim",
  "Joakim",
  "Johan",
  "Johannes",
  "John",
  "Johnnie",
  "Johnny",
  "Jon",
  "Jonas",
  "Jonathan",
  "Julius",
  "J\u00f8rgen",
  "Karl",
  "Karlo",
  "Karsten",
  "Kaspar",
  "Kasper",
  "Keld",
  "Ken",
  "Kenn",
  "Kenneth",
  "Kenny",
  "Kent",
  "Kim",
  "Kjeld",
  "Klaus",
  "Klavs",
  "Kristian",
  "Kurt",
  "K\u00e5re",
  "Lars",
  "Lasse",
  "Laurits",
  "Laus",
  "Laust",
  "Leif",
  "Lennarth",
  "Lucas",
  "Ludvig",
  "Mads",
  "Magnus",
  "Malthe",
  "Marcus",
  "Marius",
  "Mark",
  "Martin",
  "Mathias",
  "Matthias",
  "Michael",
  "Mik",
  "Mikael",
  "Mike",
  "Mikkel",
  "Mogens",
  "Morten",
  "Nick",
  "Nicklas",
  "Nicolai",
  "Nicolaj",
  "Niels",
  "Nikolai",
  "Nikolaj",
  "Nils",
  "Noah",
  "Ole",
  "Olfert",
  "Oliver",
  "Oscar",
  "Oskar",
  "Osvald",
  "Otto",
  "Ove",
  "Palle",
  "Patrick",
  "Paw",
  "Peder",
  "Per",
  "Pete",
  "Peter",
  "Paul",
  "Philip",
  "Poul",
  "Preben",
  "Ragnar",
  "Ragner",
  "Rasmus",
  "Ren\u00e9",
  "Richard",
  "Richardt",
  "Robert",
  "Robin",
  "Rolf",
  "Ron",
  "Ronni",
  "Ronnie",
  "Ronny",
  "Ruben",
  "Rune",
  "Sam",
  "Sebastian",
  "Silas",
  "Simon",
  "Sonny",
  "Steen",
  "Stefan",
  "Sten",
  "Stephan",
  "Steve",
  "Steven",
  "Stig",
  "Svenning",
  "S\u00f8ren",
  "Tage",
  "Tejs",
  "Thomas",
  "Tim",
  "Timmy",
  "Tobias",
  "Tom",
  "Tommy",
  "Tonny",
  "Torben",
  "Troels",
  "Uffe",
  "Ulf",
  "Ulrik",
  "Vagn",
  "Valdemar",
  "Verner",
  "Victor",
  "Villads",
  "Werner",
  "William",
  "Yan",
  "Yannick",
  "Yngve",
  "Zacharias",
  "Ziggy",
  "\u00d8ivind",
  "\u00d8jvind",
  "\u00d8rni",
  "\u00d8vli",
  "\u00d8ystein",
  "\u00d8yvind",
  "\u00c5bj\u00f8rn",
  "Aage",
  "\u00c5ge"
)

person_first_names_female_da_dk <- c(
  "Abelone",
  "Agnes",
  "Agnete",
  "Alberte",
  "Alma",
  "Amalie",
  "Amanda",
  "Andrea",
  "Ane",
  "Anette",
  "Anna",
  "Anne",
  "Annemette",
  "Annette",
  "Asta",
  "Astrid",
  "Benedicte",
  "Benedikte",
  "Bente",
  "Benthe",
  "Berit",
  "Berta",
  "Beth",
  "Bettina",
  "Birgit",
  "Birgitte",
  "Birte",
  "Birthe",
  "Bitten",
  "Bodil",
  "Britt",
  "Britta",
  "Camilla",
  "Carina",
  "Carla",
  "Caroline",
  "Cathrine",
  "Catrine",
  "Cecilie",
  "Charlotte",
  "Christina",
  "Christine",
  "Cirkeline",
  "Clara",
  "Connie",
  "Conny",
  "Dagmar",
  "Dagny",
  "Daniella",
  "Dina",
  "Ditte",
  "Doris",
  "Dorte",
  "Dorthe",
  "Edith",
  "Elin",
  "Elisabeth",
  "Ella",
  "Ellen",
  "Elna",
  "Else",
  "Elsebeth",
  "Emilie",
  "Emily",
  "Emma",
  "Erna",
  "Esmarelda",
  "Ester",
  "Filippa",
  "Frederikke",
  "Freja",
  "Frida",
  "Gerda",
  "Gertrud",
  "Gitte",
  "Grete",
  "Grethe",
  "Gundhild",
  "Gunhild",
  "Gurli",
  "Gyda",
  "Hannah",
  "Hanne",
  "Heidi",
  "Helen",
  "Helle",
  "Henriette",
  "Herdis",
  "Iben",
  "Ida",
  "Inga",
  "Inge",
  "Ingelise",
  "Inger",
  "Ingrid",
  "Irma",
  "Isabella",
  "Jacobine",
  "Jacqueline",
  "Janne",
  "Janni",
  "Jannie",
  "Jasmin",
  "Jean",
  "Jenny",
  "Joan",
  "Johanne",
  "Jonna",
  "Josefine",
  "Josephine",
  "Julie",
  "Justina",
  "Jytte",
  "Karen",
  "Karin",
  "Karina",
  "Karla",
  "Karoline",
  "Katcha",
  "Katja",
  "Katrine",
  "Kirsten",
  "Kirstin",
  "Kirstine",
  "Klara",
  "Kristina",
  "Kristine",
  "Laura",
  "Lea",
  "Lena",
  "Lene",
  "Leonora",
  "Line",
  "Liva",
  "Lona",
  "Lone",
  "Lotte",
  "Louise",
  "L\u00e6rke",
  "Maiken",
  "Maja",
  "Majken",
  "Malene",
  "Malou",
  "Maren",
  "Margit",
  "Margrethe",
  "Maria",
  "Marianne",
  "Marie",
  "Marlene",
  "Mathilde",
  "Maya",
  "Merete",
  "Merethe",
  "Mette",
  "Mia",
  "Michala",
  "Michelle",
  "Mie",
  "Mille",
  "Mimi",
  "Minna",
  "Nadia",
  "Naja",
  "Nana",
  "Nanna",
  "Nanni",
  "Natasha",
  "Natasja",
  "Nete",
  "Nicoline",
  "Nina",
  "Nora",
  "Oda",
  "Odeline",
  "Odette",
  "Ofelia",
  "Olga",
  "Olivia",
  "Patricia",
  "Paula",
  "Paulina",
  "Pernille",
  "Pia",
  "Ragna",
  "Ragnhild",
  "Randi",
  "Rebecca",
  "Regitse",
  "Regitze",
  "Rikke",
  "Rita",
  "Ritt",
  "Ronja",
  "Rosa",
  "Ruth",
  "Sabine",
  "Sandra",
  "Sanne",
  "Sara",
  "Sarah",
  "Selma",
  "Signe",
  "Sigrid",
  "Silje",
  "Sille",
  "Simone",
  "Sine",
  "Sofia",
  "Sofie",
  "Solveig",
  "Solvej",
  "Sonja",
  "Sophie",
  "Stina",
  "Stine",
  "Susanne",
  "Sussanne",
  "Sussie",
  "Sys",
  "S\u00f8rine",
  "S\u00f8s",
  "Tammy",
  "Tanja",
  "Thea",
  "Tilde",
  "Tina",
  "Tine",
  "Tove",
  "Trine",
  "Ulla",
  "Ulrike",
  "Ursula",
  "Vera",
  "Victoria",
  "Viola",
  "Vivian",
  "Weena",
  "Winni",
  "Winnie",
  "Xenia",
  "Yasmin",
  "Yda",
  "Yrsa",
  "Yvonne",
  "Zahra",
  "Zara",
  "Zehnia",
  "Zelma",
  "Zenia",
  "\u00c5se"
)

person_first_names_da_dk <- c(person_first_names_male_da_dk, person_first_names_female_da_dk)

person_last_names_da_dk <- c(
  "Jensen",
  "Nielsen",
  "Hansen",
  "Pedersen",
  "Andersen",
  "Christensen",
  "Larsen",
  "S\u00f8rensen",
  "Rasmussen",
  "Petersen",
  "J\u00f8rgensen",
  "Madsen",
  "Kristensen",
  "Olsen",
  "Christiansen",
  "Thomsen",
  "Poulsen",
  "Johansen",
  "Knudsen",
  "Mortensen",
  "M\u00f8ller",
  "Jacobsen",
  "Jakobsen",
  "Olesen",
  "Frederiksen",
  "Mikkelsen",
  "Henriksen",
  "Laursen",
  "Lund",
  "Schmidt",
  "Eriksen",
  "Holm",
  "Kristiansen",
  "Clausen",
  "Simonsen",
  "Svendsen",
  "Andreasen",
  "Iversen",
  "Jeppesen",
  "Mogensen",
  "Jespersen",
  "Nissen",
  "Lauridsen",
  "Frandsen",
  "\u00d8stergaard",
  "Jepsen",
  "Kj\u00e6r",
  "Carlsen",
  "Vestergaard",
  "Jessen",
  "N\u00f8rgaard",
  "Dahl",
  "Christoffersen",
  "Skov",
  "S\u00f8ndergaard",
  "Bertelsen",
  "Bruun",
  "Lassen",
  "Bach",
  "Gregersen",
  "Friis",
  "Johnsen",
  "Steffensen",
  "Kjeldsen",
  "Bech",
  "Krogh",
  "Lauritsen",
  "Danielsen",
  "Mathiesen",
  "Andresen",
  "Brandt",
  "Winther",
  "Toft",
  "Ravn",
  "Mathiasen",
  "Dam",
  "Holst",
  "Nilsson",
  "Lind",
  "Berg",
  "Schou",
  "Overgaard",
  "Kristoffersen",
  "Schultz",
  "Klausen",
  "Karlsen",
  "Paulsen",
  "Hermansen",
  "Thorsen",
  "Koch",
  "Thygesen"
)

person_prefixes_male_da_dk <- c(
  "Hr", "Dr.", "Prof.", "Univ.Prof."
)

person_prefixes_female_da_dk <- c(
  "Fru", "Dr.", "Prof.", "Univ.Prof."
)

person_da_dk <- list(
  first_names = person_first_names_da_dk,
  first_names_male = person_first_names_male_da_dk,
  first_names_female = person_first_names_female_da_dk,
  last_names = person_last_names_da_dk,
  prefixes_female = person_prefixes_female_da_dk,
  prefixes_male = person_prefixes_male_da_dk
)
